==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QAudioOutputSelectorControl_shell.h <==
#ifndef QAUDIOOUTPUTSELECTORCONTROL_SHELL_H
#define QAUDIOOUTPUTSELECTORCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiooutputselectorcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAudioOutputSelectorControl_shell : public QAudioOutputSelectorControl, public QtJambiShellInterface
{
public:
    QAudioOutputSelectorControl_shell(QObject* parent0 = nullptr);
    ~QAudioOutputSelectorControl_shell() override;

    QString activeOutput() const override;
    QList<QString> availableOutputs() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QString defaultOutput() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString outputDescription(const QString& name0) const override;
    void setActiveOutput(const QString& name0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioOutputSelectorControl_access : public QAudioOutputSelectorControl
{
    jstring __qt_activeOutput(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_availableOutputs(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_defaultOutput(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_outputDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    void __qt_setActiveOutput_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
};

#endif // QAUDIOOUTPUTSELECTORCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QAudioOutputSelectorControl_shell.h <==
#ifndef QAUDIOOUTPUTSELECTORCONTROL_SHELL_H
#define QAUDIOOUTPUTSELECTORCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiooutputselectorcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAudioOutputSelectorControl_shell : public QAudioOutputSelectorControl, public QtJambiShellInterface
{
public:
    QAudioOutputSelectorControl_shell(QObject* parent0 = nullptr);
    ~QAudioOutputSelectorControl_shell() override;

    QString activeOutput() const override;
    QList<QString> availableOutputs() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QString defaultOutput() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QString outputDescription(const QString& name0) const override;
    void setActiveOutput(const QString& name0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioOutputSelectorControl_access : public QAudioOutputSelectorControl
{
    jstring __qt_activeOutput_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_availableOutputs_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_defaultOutput_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_outputDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    void __qt_setActiveOutput_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0);
};

#endif // QAUDIOOUTPUTSELECTORCONTROL_SHELL_H
